==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Ім&apos;я процесу</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Командний рядок</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Час початку</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Читання диска</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис диска</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Підкачка</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Загалом</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Вивантаження</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читання диска</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис диска</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Примусово завершити програму</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Темна тема</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Завершити програму</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Завершення цієї програми може призвести до втрати даних.
Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Компактний режим</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Підкачка</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Загалом</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Вивантаження</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Немає відповіді</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Завершити процес</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Завершення цього процесу може призвести до втрати даних.
Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Призупинити процес</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Відновити процес</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Переглянути місце розташування процесу</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Властивості</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 програм і %3 процесів запущено</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис диску</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читання диска</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Вивантаження</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Системний Монітор Deepin - це інтуїтивно зрозумілий і потужний системний монітор. Він може контролювати процес ЦП, пам&apos;ять, мережу, диск і інший статус.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Системний Монітор Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Системний Монітор Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - служба ініціації процесу</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Стільниця</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Polkit proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Launcher</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Док</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Екранний дисплей</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Демон</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Сесійний демон</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - процес ініціалізації сеансу</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Демон Deepin File Manager</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Служба блокування екрану</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Менеджер вікон Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Перемикач Менеджера Вікон Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Повідомлення Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Агент Хмарного Друкування Deepin</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Сервіс меню Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Демон Магазину Deepin</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Демон вікна відповідності</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Демон вікна відповідності DBus служби</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH агент</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Демон віртуальної файлової системи в режимі користувача</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Демон запобіжного серверу віртуальної файлової системи користувацького режиму</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Допоміжний процес клієнта Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Менеджер мережі</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Служба PolicyKit DBus</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Демон служби обміну файлами</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Х сервіс</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Метод вводу Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Демон методу вводу Fcitx DBus</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Демон методу введення Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Локальний клієнт ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Звуковий сервіс</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Демон друку</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Дисплей з підсвічуванням</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Менеджер системних служб</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Менеджер системних служб - Демон керування пристроями</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Демон диску</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Демон облікового запису</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Демон DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Демон подій миші</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Сервіс DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Демон Gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Демон Bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Демон живлення</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Диспетчер модемів</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Обслуговування системного лотка</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Пісочниця веб-переглядача Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Демон демонтажу сенсорної панелі Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Підкачка</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Демон методу введення Sogou</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Натисніть програму, яку потрібно завершити</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Мої процеси</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Всі процеси</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Лоток</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Ім&apos;я процесу</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Командний рядок</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Час початку</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Примусово завершити програму</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Темна тема</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Завершити програму</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Завершення цієї програми може призвести до втрати даних.
Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Загалом</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Вивантаження</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Немає відповіді</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Завершити процес</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Завершення цього процесу може призвести до втрати даних.
Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Призупинити процес</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Відновити процес</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Переглянути місце розташування процесу</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Властивості</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 програм і %3 процесів запущено</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Пам&apos;ять</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Запис диску</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Читати диску</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Вивантаження</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Системний Монітор Deepin - це інтуїтивно зрозумілий і потужний системний монітор. Він може контролювати процес ЦП, пам&apos;ять, мережу, диск і інший статус.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Системний Монітор Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Системний Монітор Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - служба ініціації процесу</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Стільниця</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Polkit proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Launcher</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Док</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Екранний дисплей</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Демон</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Сесійний демон</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - процес ініціалізації сеансу</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Демон Deepin File Manager</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Служба блокування екрану</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Менеджер вікон Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Перемикач Менеджера Вікон Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Повідомлення Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Агент Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Сервіс меню Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Демон Магазину Deepin</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Демон вікна відповідності</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Демон вікна відповідності DBus служби</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH агент</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Демон віртуальної файлової системи в режимі користувача</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Демон запобіжного серверу віртуальної файлової системи користувацького режиму</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Допоміжний процес клієнта Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Менеджер мережі</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Служба PolicyKit DBus</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Демон служби обміну файлами</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Х сервіс</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Метод вводу Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Демон методу вводу Fcitx DBus</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Демон методу введення Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Локальний клієнт ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Звуковий сервіс</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Демон друку</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Дисплей з підсвічуванням</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Менеджер системних служб</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Менеджер системних служб - Демон керування пристроями</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Демон диску</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Демон облікового запису</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Демон DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Демон подій миші</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Сервіс DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Демон Gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Демон Bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Демон живлення</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Диспетчер модемів</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Обслуговування системного лотка</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Пісочниця веб-переглядача Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Демон демонтажу сенсорної панелі Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Не ввімкнено</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Натисніть програму, яку потрібно завершити</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Мої процеси</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Всі процеси</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
</TS>
